import re
import ast
from threading import Thread
from datetime import datetime
from bitly_api import BitlyAPI
from csv_file_handler import CSVFileReader, CSVFileWriter


class BitlyRetriever(Thread):
    def __init__(self, collection_file_path, bitly_file_path, token_id, logger):
        Thread.__init__(self)

        self.collection_file_path = collection_file_path
        self.bitly_file_path = bitly_file_path
        self.bitly_api = BitlyAPI(token_id, logger)

    def run(self):
        collection_file_reader = CSVFileReader(self.collection_file_path)
        bitly_file_writer = CSVFileWriter(self.bitly_file_path)

        bitly_file_writer.write_columns(BitlyRetriever.get_headers())

        while True:
            line = collection_file_reader.next_line()
            columns = line.split('|')

            if line is '':
                break

            if re.search('https?://(www.)?bit.ly/', columns[8]):
                urls = ast.literal_eval(columns[8])

                all_clicks_list = []
                clicks_from_twitter_list = []
                all_clicks_since_posting_list = []
                clicks_from_twitter_since_posting_list = []
                end_url_list = []
                created_at_list = []
                retrieved_at = ''

                for u in urls:

                    match = re.match('https?://(www.)?bit.ly/[\w-]*', u)

                    if match is not None:
                        url = match.group(0)

                        [all_clicks, clicks_from_twitter] = self.bitly_api.get_clicks_since_creation(url)
                        posting_date = datetime.strptime(columns[1], '%a %b %d %H:%M:%S +0000 %Y')
                        [all_clicks_since_posting, clicks_from_twitter_since_posting] = self.bitly_api.get_clicks_since_posting(url, posting_date)
                        end_url = self.bitly_api.get_end_url(url)
                        created_at = self.bitly_api.get_created_at(url)
                        all_clicks_list.append(all_clicks)
                        clicks_from_twitter_list.append(clicks_from_twitter)
                        all_clicks_since_posting_list.append(all_clicks_since_posting)
                        clicks_from_twitter_since_posting_list.append(clicks_from_twitter_since_posting)
                        end_url_list.append(end_url)
                        created_at_list.append(created_at)
                        retrieved_at = datetime.utcnow().strftime('%a %b %d %H:%M:%S +0000 %Y')
                    else:
                        all_clicks_list.append(-2)
                        clicks_from_twitter_list.append(-2)
                        all_clicks_since_posting_list.append(-2)
                        clicks_from_twitter_since_posting_list.append(-2)
                        end_url_list.append('')
                        created_at_list.append('')

                bitly_file_writer.write_columns([columns[0],
                                                 all_clicks_list,
                                                 clicks_from_twitter_list,
                                                 all_clicks_since_posting_list,
                                                 clicks_from_twitter_since_posting_list,
                                                 end_url_list,
                                                 created_at_list,
                                                 retrieved_at])

        collection_file_reader.close()
        bitly_file_writer.close()

    @staticmethod
    def get_headers():
        return ['tweet_id',
                'bitly_all_clicks',
                'bitly_twitter_clicks',
                'bitly_all_clicks_since_posting',
                'bitly_twitter_clicks_since_posting',
                'bitly_end_url_string',
                'bitly_created_at',
                'bitly_data_retrieved_at']
