class ConfigManager:
    def __init__(self, config_path):
        self.twitter_configs = []
        self.bitly_configs = []
        self.collection_config = None
        self.folders_config = None
        self.current_twitter_config = 0
        self.current_bilty_config = 0

        self.read_file(config_path)

    def read_file(self, config_path):
        lines = []
        file = open(config_path, 'r')
        for line in file:
            if (line[-1] == '\n'):
                lines.append(line[:-1])
            else:
                lines.append(line)

        for i in range(0, len(lines)):
            line = lines[i]
            if line.startswith('#Twitter'):
                access_token = lines[i + 1].split('=')[1]
                access_secret = lines[i + 2].split('=')[1]
                consumer_key = lines[i + 3].split('=')[1]
                consumer_secret = lines[i + 4].split('=')[1]
                i += 4
                self.twitter_configs.append(TwitterConfig(access_token, access_secret, consumer_key, consumer_secret))
            elif line.startswith('#Bitly'):
                token = lines[i + 1].split('=')[1]
                i += 1
                self.bitly_configs.append(BitlyConfig(token))
            elif line.startswith('#Collection'):
                collection_time = lines[i + 1].split('=')[1]
                collection_interval = lines[i + 2].split('=')[1]
                extra_data_delay = lines[i + 3].split('=')[1]
                i += 3
                self.collection_config = CollectionConfig(collection_time, collection_interval, extra_data_delay)
            elif line.startswith('#Folders'):
                collections_folder = lines[i + 1].split('=')[1]
                logs_folder = lines[i + 2].split('=')[1]
                i += 2
                self.folders_config = FoldersConfig(collections_folder, logs_folder)

    def get_twitter_config(self):
        return self.twitter_configs[self.current_twitter_config]

    def get_next_twitter_config(self):
        self.current_twitter_config = (self.current_twitter_config + 1) % len(self.twitter_configs)
        return self.get_twitter_config()

    def get_bitly_config(self):
        return self.bitly_configs[self.current_bilty_config]

    def get_next_bitly_config(self):
        self.current_bilty_config = (self.current_bilty_config + 1) % len(self.bitly_configs)
        return self.get_bitly_config()

class TwitterConfig:
    def __init__(self, access_token, access_secret, consumer_key, consumer_secret):
        self.access_token = access_token
        self.access_secret = access_secret
        self.consumer_key = consumer_key
        self.consumer_secret = consumer_secret


class BitlyConfig:
    def __init__(self, token):
        self.token = token


class CollectionConfig:
    def __init__(self, collection_time, collection_interval, extra_data_delay):
        self.collection_time = int(collection_time)
        self.collection_interval = int(collection_interval)
        self.extra_data_delay = int(extra_data_delay)

class FoldersConfig:
    def __init__(self, collections_folder, logs_folder):
        self.collections_folder = collections_folder
        self.logs_folder = logs_folder
