import io


class CSVFileWriter:
    def __init__(self, file_path, append=True, separator='|', batch_threshold=100):
        self.file_path = file_path
        self.separator = separator
        self.batch = ''
        self.batch_size = 0
        self.batch_threshold = batch_threshold

        if append:
            self.file = io.open(file_path, 'a', encoding='utf8')
        else:
            self.file = io.open(file_path, 'w', encoding='utf8')

    def __del__(self):
        if self.batch_size > 0:
            self.write_batch()
        self.close()

    def write_columns(self, columns):
        column_string = ''
        for column in columns:
            column_string += (str(column).replace('|', '§').replace('\r', '').replace('\n', '').replace('\x0b', '')
                              .replace('\x0c', '').replace('\x1c', '').replace('\x1d', '').replace('\x1e', '')
                              .replace('\x85', '').replace('\u2028', '').replace('\u2029', '') + '|')

        # Get rid of trailing '|' by using [:-1]
        if column_string is not '':
            self.batch += column_string[:-1] + '\n'
            self.batch_size += 1

        if self.batch_size >= self.batch_threshold:
            self.write_batch()

    def write_batch(self):
        self.file.write(self.batch)
        self.file.flush()

        self.batch = ''
        self.batch_size = 0

    def close(self):
        if self.batch_size > 0:
            self.write_batch()
        self.file.close()


class CSVFileReader:
    def __init__(self, file_path, skip_header=True, separator='|'):
        self.file_path = file_path
        self.skip_header = skip_header
        self.separator = separator
        self.file = io.open(file_path, 'r', encoding='utf8')
        self.line_counter = 0

    def __del__(self):
        self.close()

    def next_line(self):
        if self.skip_header and self.line_counter == 0:
            self.file.readline()

        self.line_counter += 1
        return self.file.readline()

    def close(self):
        self.file.close()
