from retweets_retriever import RetweetRetriever
from bitly_retriever import BitlyRetriever
from logger import Logger
from multiprocessing import Process


class ExtraDataRetriever:
    def __init__(self, log_path):
        self.logger = Logger(log_path)

    def start_retrieving(self, collection_file_path, retweets_file_path, bitly_file_path, bitly_token_id):
        retrieve_process = Process(target=self.retrieve_extra_data, args=(collection_file_path,
                                                                          retweets_file_path,
                                                                          bitly_file_path,
                                                                          bitly_token_id,
                                                                          self.logger))
        retrieve_process.start()

        return retrieve_process

    def retrieve_extra_data(self, collection_file_path, retweets_file_path, bitly_file_path, bitly_token_id, logger):
        self.logger.log('Extra Data Retriever/retrieve_extra_data', 'Retrieving extra data')
        retweets_retriever = RetweetRetriever(collection_file_path, retweets_file_path, logger)
        bitly_retriever = BitlyRetriever(collection_file_path, bitly_file_path, bitly_token_id, logger)

        retweets_retriever.start()
        bitly_retriever.start()

        retweets_retriever.join()
        bitly_retriever.join()

        self.logger.log('Extra Data Retriever/retrieve_extra_data', 'Done retrieving extra data')

        exit()

