import tweepy
from time import time, sleep

class Listener(tweepy.StreamListener):

    def __init__(self, conn, end_time, logger):
        super(Listener, self).__init__()

        self.conn = conn
        self.end_time = end_time
        self.logger = logger
        self.wait_time = 60

    def on_status(self, status):
        self.wait_time = 60

        self.conn.send(status)

        if time() >= self.end_time:
            raise StopStreamingException('Stop Streaming')

    def on_error(self, status_code):
        self.logger.log('Listener/on_error', 'Error!', str(status_code))
        if status_code == 420:
            self.logger.log('Listener/on_error', 'Rate limit reached will sleep ' + str(self.wait_time) + ' seconds!')
            sleep(self.wait_time)

            self.wait_time *= 2

            return True

        return False

    def on_exception(self, exception):
        self.logger.log('Listener/on_error', 'Exception!', str(exception))
        return True


class StopStreamingException(Exception):
    pass
