from datetime import datetime
from threading import Thread
from csv_file_handler import CSVFileReader, CSVFileWriter
from twitter_api import TwitterApi


class RetweetRetriever(Thread):
    def __init__(self, collection_file_path, retweets_file_path, logger):
        Thread.__init__(self)

        self.collection_file_path = collection_file_path
        self.retweets_file_path = retweets_file_path
        self.logger = logger

        self.twitter_api = TwitterApi(self.logger.get_path())
        self.twitter_api.create_api()

    def run(self):
        collection_file_reader = CSVFileReader(self.collection_file_path)
        retweet_file_writer = CSVFileWriter(self.retweets_file_path)

        retweet_file_writer.write_columns(RetweetRetriever.get_headers())

        ids_to_retrieve = []
        while True:
            line = collection_file_reader.next_line()

            if line is '':
                break

            tweet_id = line.split('|')[0]
            ids_to_retrieve.append(tweet_id)

            if len(ids_to_retrieve) == 100:
                self.retrieve_retweets_in_batch(ids_to_retrieve, retweet_file_writer)
                ids_to_retrieve = []

        if len(ids_to_retrieve) > 0:
            self.retrieve_retweets_in_batch(ids_to_retrieve, retweet_file_writer)

        collection_file_reader.close()
        retweet_file_writer.close()

    def retrieve_retweets_in_batch(self, ids_to_retrieve, retweet_file_writer):
        retweets = self.twitter_api.get_retweets(ids_to_retrieve)

        for tweet_id in retweets:
            retweet_file_writer.write_columns([tweet_id,
                                               retweets[tweet_id],
                                               datetime.utcnow().strftime('%a %b %d %H:%M:%S +0000 %Y')])

    @staticmethod
    def get_headers():
        return [
            'tweet_id',
            'retweet_count',
            'retweets_retrieved_at'
        ]
