from csv_file_handler import CSVFileWriter


class TweetWriter:
    def __init__(self):
        self.file_writer = None

    def write(self, tweet):
        data = TweetWriter.extract_data(tweet)
        self.file_writer.write_columns(data)

    def change_file(self, new_file_path):
        if self.file_writer is not None:
            self.file_writer.close()

        self.file_writer = CSVFileWriter(new_file_path)
        headers = TweetWriter.get_headers()
        self.file_writer.write_columns(headers)

    @staticmethod
    def extract_data(tweet):
        all_data = tweet._json

        hashtags = []
        for h in all_data['entities']['hashtags']:
            hashtags.append(h['text'])

        urls = []
        for u in all_data['entities']['urls']:
            urls.append(u['expanded_url'])

        place_id = ''
        place_full_name = ''
        place_country_code = ''
        if all_data['place'] is not None:
            place_id = all_data['place']['id']
            place_full_name = all_data['place']['full_name']
            place_country_code = all_data['place']['country_code']

        coordinates = ''
        if all_data['geo'] is not None:
            coordinates = all_data['geo']['coordinates']

        contains_retweet = False
        if 'retweeted_status' in all_data:
            contains_retweet = True

        data = [all_data['id_str'],
                all_data['created_at'],
                place_id,
                place_full_name,
                place_country_code,
                coordinates,
                all_data['lang'],
                hashtags,
                urls,
                contains_retweet,
                all_data['in_reply_to_status_id_str'],
                all_data['user']['id_str'],
                all_data['user']['created_at'],
                all_data['user']['followers_count'],
                all_data['user']['friends_count'],
                all_data['user']['statuses_count'],
                all_data['user']['favourites_count'],
                all_data['user']['verified'],
                all_data['user']['lang']]

        return data

    @staticmethod
    def get_headers():
        return ['tweet_id',
                'tweet_created_at',
                'tweet_place_id',
                'tweet_place_full_name',
                'tweet_place_country_code',
                'tweet_geo_coordinates',
                'tweet_language',
                'tweet_hashtags',
                'tweet_urls',
                'tweet_contains_retweet',
                'tweet_in_reply_to_status_id',
                'user_id',
                'user_created_at',
                'user_followers_count',
                'user_friends_count',
                'user_statuses_count',
                'user_favourites_count',
                'user_verified',
                'user_language'
                ]
